@@ -47,27 +47,24 @@ def add_interaction_effect(df:pd.DataFrame, column_label_a:str, column_label_b:s
     df[interaction_name] = df[column_label_a] * df[column_label_b]
     return interaction_name
 
-def add_day_of_week_dummies(df:pd.DataFrame, date_label:str=None) -> Tuple[List[str], pd.DataFrame]:
+def add_day_of_week_dummies(df:pd.DataFrame, date_label:str=None):
     if date_label is None:
         dates_index = pd.to_datetime(df.index)
         date_label = '_date'
         df[date_label] = dates_index
         
     else:
-        dates_index = pd.to_datetime(df[date_label])
+        dates_index = pd.to_datetime(df[date_label],format='%Y/%m/%d')
     add_constant(df)
     df['day_of_week'] = dates_index.dt.day_name()
     df['day_of_week'] = df['day_of_week'].str.lower()
-    dummies = pd.get_dummies(df['day_of_week'])
+    dummies = pd.get_dummies(df['day_of_week'])       
     dummies[date_label] = df['date']
     
-#     dummies[date_label] = dates_index
-    
     df = pd.merge(df, dummies, left_on=date_label, right_on=date_label, how='left')
-    
     df.drop(['day_of_week'], axis=1, inplace=True)
-    
-    df.drop(['_date'], axis=1, inplace=True) # in case we added it
+    df.drop(['date'], axis=1, inplace=True)
+    # df.drop(['_date'], axis=1, inplace=True) # in case we added it
     dummies.drop([date_label], axis=1, inplace=True)
     
     return list(dummies.columns), df
